pygeodesy.errors.ClipError

Package pygeodesy :: Module errors :: Class ClipError |
[frames] | no frames]

# Class ClipError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
                   exceptions.ValueError --+
                                           |
                                 _ValueError --+
                                               |
                                              ClipError

Clip box or clip region issue.

Instance Methods
__init__(self, *name_n_corners, **txt_cause) New ClipError. |
Inherited from `exceptions.ValueError`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__ (self, *name_n_corners, **txt_cause) (Constructor) |
New ClipError. Arguments: `name_n_corners` - Either just a name (`str`) or name, number, corners (`str`, `int`, `tuple`). `txt_cause` - Optional `txt=str` explanation of the error and `cause=None` for exception chaining. Overrides: object.__init__